==> cscec5b-fbxt-impl-3.0.0-20201216.080050-67-sources.jar: com/ejianc/business/fbxt/odd/bean/OddRedirectEntity.java <==
package com.ejianc.business.fbxt.odd.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 零星用工转扣实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_fbxt_odd_redirect")
public class OddRedirectEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="info_id")
    private Long infoId; // 清单主键
    @TableField(value="contract_id")
    private String contractId; // 转扣合同主键
    @TableField(value="contract_name")
    private String contractName; // 转扣合同名称
    @TableField(value="mny")
    private java.math.BigDecimal mny; // 转扣金额
    @TableField(value="contract_code")
    private String contractCode; // 转扣合同编号
    @TableField(value="odd_id")
    private Long oddId; // 零星用工主键
    
    
    

    /**
     * 清单主键
     */
    public Long getInfoId() {
        return infoId;
    }

    /**
     * 清单主键
     */
    public void setInfoId(Long infoId) {
        this.infoId = infoId;
    }
    /**
     * 转扣合同主键
     */
    public String getContractId() {
        return contractId;
    }

    /**
     * 转扣合同主键
     */
    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    /**
     * 转扣合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 转扣合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 转扣金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 转扣金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 转扣合同编号
     */
    public String getContractCode() {
        return contractCode;
    }

    /**
     * 转扣合同编号
     */
    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 零星用工主键
     */
    public Long getOddId() {
        return oddId;
    }

    /**
     * 零星用工主键
     */
    public void setOddId(Long oddId) {
        this.oddId = oddId;
    }
    
}

==> cscec5b-fbxt-impl-3.0.0-20210201.105805-148-sources.jar: com/ejianc/business/fbxt/odd/bean/OddRedirectEntity.java <==
package com.ejianc.business.fbxt.odd.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 零星用工转扣实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_fbxt_odd_redirect")
public class OddRedirectEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="info_id")
    private Long infoId; // 清单主键
    @TableField(value="contract_id")
    private String contractId; // 转扣合同主键
    @TableField(value="contract_name")
    private String contractName; // 转扣合同名称
    @TableField(value="mny")
    private java.math.BigDecimal mny; // 转扣金额
    @TableField(value="contract_code")
    private String contractCode; // 转扣合同编号
    @TableField(value="odd_id")
    private Long oddId; // 零星用工主键
    @TableField(value = "redirect_nc_flag")
    private Integer redirectNcFlag; // nc是否结算，0-否，1-是


    public Integer getRedirectNcFlag() {
        return redirectNcFlag;
    }

    public void setRedirectNcFlag(Integer redirectNcFlag) {
        this.redirectNcFlag = redirectNcFlag;
    }

    /**
     * 清单主键
     */
    public Long getInfoId() {
        return infoId;
    }

    /**
     * 清单主键
     */
    public void setInfoId(Long infoId) {
        this.infoId = infoId;
    }
    /**
     * 转扣合同主键
     */
    public String getContractId() {
        return contractId;
    }

    /**
     * 转扣合同主键
     */
    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    /**
     * 转扣合同名称
     */
    public String getContractName() {
        return contractName;
    }

    /**
     * 转扣合同名称
     */
    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    /**
     * 转扣金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 转扣金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 转扣合同编号
     */
    public String getContractCode() {
        return contractCode;
    }

    /**
     * 转扣合同编号
     */
    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 零星用工主键
     */
    public Long getOddId() {
        return oddId;
    }

    /**
     * 零星用工主键
     */
    public void setOddId(Long oddId) {
        this.oddId = oddId;
    }
    
}
